==> App-UniqFiles-0.143.tar.gz: App-UniqFiles-0.143/lib/App/UniqFiles.pm <==
package App::UniqFiles;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2024-12-05'; # DATE
our $DIST = 'App-UniqFiles'; # DIST
our $VERSION = '0.143'; # VERSION

1;
# ABSTRACT: Report unique/duplicate file {names,contents}

__END__

=pod

=encoding UTF-8

=head1 NAME

App::UniqFiles - Report unique/duplicate file {names,contents}

=head1 VERSION

This document describes version 0.143 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2024-12-05.

=head1 SYNOPSIS

 # See scripts: uniq-files, dupe-files

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-UniqFiles>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-UniqFiles>.

=head1 SEE ALSO

L<File::FindUniq> is the backend used by the scripts in this distribution.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTOR

=for stopwords Steven Haryanto

Steven Haryanto <stevenharyanto@gmail.com>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-UniqFiles>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> App-UniqFiles-0.143.1.tar.gz: App-UniqFiles-0.143.1/lib/App/UniqFiles.pm <==
package App::UniqFiles;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2024-12-05'; # DATE
our $DIST = 'App-UniqFiles'; # DIST
our $VERSION = '0.143.1'; # VERSION

1;
# ABSTRACT: Report unique/duplicate file {names,contents}

__END__

=pod

=encoding UTF-8

=head1 NAME

App::UniqFiles - Report unique/duplicate file {names,contents}

=head1 VERSION

This document describes version 0.143.1 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2024-12-05.

=head1 SYNOPSIS

 # See scripts: uniq-files, dupe-files

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-UniqFiles>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-UniqFiles>.

=head1 SEE ALSO

L<File::FindUniq> is the backend used by the scripts in this distribution.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTOR

=for stopwords Steven Haryanto

Steven Haryanto <stevenharyanto@gmail.com>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2024 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-UniqFiles>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
